clophfit.prtecan
----------------

.. automodule:: clophfit.prtecan
   :show-inheritance: Titration
   :special-members: __almost_eq__

..
   .. autoclass:: Titration
      :show-inheritance: True

..
   .. autoclass:: Tecanfile
	  :exclude-members: path
